@@ -23,11 +23,8 @@ OAuth 1.0 Yahoo backend
     Throws:
         AuthUnknownError - if user data retrieval fails (guid or profile)
 """
-import json
-
-from social.exceptions import AuthUnknownError
 from social.backends.open_id import OpenIdAuth
-from social.backends.oauth import ConsumerBasedOAuth
+from social.backends.oauth import BaseOAuth1
 
 
 class YahooOpenId(OpenIdAuth):
@@ -36,7 +33,7 @@ class YahooOpenId(OpenIdAuth):
     URL = 'http://me.yahoo.com'
 
 
-class YahooOAuth(ConsumerBasedOAuth):
+class YahooOAuth(BaseOAuth1):
     """Yahoo OAuth authentication backend"""
     name = 'yahoo-oauth'
     ID_KEY = 'guid'
@@ -66,28 +63,18 @@ class YahooOAuth(ConsumerBasedOAuth):
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
-        guid = self._get_guid(access_token)
-        url = 'http://social.yahooapis.com/v1/user/%s/profile?format=json' \
-                    % guid
-        request = self.oauth_request(access_token, url)
-        response = self.fetch_response(request)
-        try:
-            return json.loads(response)['profile']
-        except ValueError:
-            raise AuthUnknownError('Error during profile retrieval, '
-                                   'please, try again later')
+        return self.get_json(
+            'http://social.yahooapis.com/v1/user/%s/profile?format=json' %
+                self._get_guid(access_token),
+            auth=self.oauth_auth(access_token)
+        )['profile']
 
     def _get_guid(self, access_token):
         """
             Beause you have to provide GUID for every API request
             it's also returned during one of OAuth calls
         """
-        url = 'http://social.yahooapis.com/v1/me/guid?format=json'
-        request = self.oauth_request(access_token, url)
-        response = self.fetch_response(request)
-        try:
-            data = json.loads(response)
-            return data['guid']['value']
-        except ValueError:
-            raise AuthUnknownError('Error during user id retrieval, '
-                                   'please, try again later')
+        return self.get_json(
+            'http://social.yahooapis.com/v1/me/guid?format=json',
+            auth=self.oauth_auth(access_token)
+        )['guid']['value']
